@@ -1,34 +1,19 @@
 <?php
 
-/**
- * Copyright 2005-2022 Centreon
- * Centreon is developed by : Julien Mathis and Romain Le Merlus under
- * GPL Licence 2.0.
+/*
+ * Copyright 2005 - 2025 Centreon (https://www.centreon.com/)
  *
- * This program is free software; you can redistribute it and/or modify it under
- * the terms of the GNU General Public License as published by the Free Software
- * Foundation ; either version 2 of the License.
+ * Licensed under the Apache License, Version 2.0 (the "License");
+ * you may not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
  *
- * This program is distributed in the hope that it will be useful, but WITHOUT ANY
- * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
- * PARTICULAR PURPOSE. See the GNU General Public License for more details.
+ * https://www.apache.org/licenses/LICENSE-2.0
  *
- * You should have received a copy of the GNU General Public License along with
- * this program; if not, see <http://www.gnu.org/licenses>.
- *
- * Linking this program statically or dynamically with other modules is making a
- * combined work based on this program. Thus, the terms and conditions of the GNU
- * General Public License cover the whole combination.
- *
- * As a special exception, the copyright holders of this program give Centreon
- * permission to link this program with independent modules to produce an executable,
- * regardless of the license terms of these independent modules, and to copy and
- * distribute the resulting executable under terms of Centreon choice, provided that
- * Centreon also meet, for each linked independent module, the terms  and conditions
- * of the license of that module. An independent module is a module which is not
- * derived from this program. If you modify this program, you may extend this
- * exception to your version of the program, but you are not obliged to do so. If you
- * do not wish to do so, delete this exception statement from your version.
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
  *
  * For more information : contact@centreon.com
  *
@@ -96,48 +81,50 @@ function createTranslationFile(
     string $translationFile,
     string $destinationFile
 ): void {
-
     $translations = [];
     $englishTranslation = [];
     $isDefaultTranslation = $languageCode === 'en';
 
+    $id = null;
+    $translation = null;
+
     if ($fleHandler = fopen($translationFile, 'r')) {
         while (false !== ($line = fgets($fleHandler))) {
             $line = trim($line);
 
-            // Retrieves the token
-            $token = trim(
-                substr($line, 0, TOKEN_LENGTH)
-            );
-            // Retrieves text after the token
-            $text = trim(
-                substr(
-                    $line,
-                    TOKEN_LENGTH,
-                    strlen($line) - TOKEN_LENGTH
-                )
-            );
             // Removes double-quotes character that surround the text
-            $text = substr($text, 1, strlen($text) - 2);
-
-            switch ($token) {
-                case 'msgid': // Token that contains the translation label
-                    $label = $text;
-                    break;
-                case 'msgstr': // Token that contains the translation
-                    if (!empty($label)) {
-                        $englishTranslation[$label] = $label;
-                        if (!$isDefaultTranslation) {
-                            // Only if the code of language is not 'en'
-                            $translations[$label] = $text;
-                        }
-                        $label = null;
-                    }
+            if (preg_match('/^(?:(msgid|msgstr)\s+)?"(.*)"\s*$/', $line, $matches)) {
+                if ($matches[1] === 'msgid') {
+                    $id = $matches[2];
+                    $translation = null;
+                } elseif ($matches[1] === 'msgstr') {
+                    $translation = $matches[2];
+                } elseif ($id !== null && $translation === null) {
+                    $id .= $matches[2];
+                } elseif ($id !== null && $translation !== null) {
+                    $translation .= $matches[2];
+                }
+            } elseif (!empty($id) && !empty($translation)) {
+                $englishTranslation[$id] = $id;
+                if (!$isDefaultTranslation) {
+                    // Only if the code of language is not 'en'
+                    $translations[$id] = $translation;
+                }
+                $id = null;
+                $translation = null;
             }
         }
 
         fclose($fleHandler);
     }
+
+    if (!empty($id) && !empty($translation)) {
+        $englishTranslation[$id] = $id;
+        if (!$isDefaultTranslation) {
+            $translations[$id] = $translation;
+        }
+    }
+
     $final['en'] = $englishTranslation;
     if (!$isDefaultTranslation) {
         // Only if the code of language is not 'en'
