@@ -2,10 +2,13 @@ export { default as userAtom } from './userAtom';
 export { default as aclAtom } from './aclAtom';
 export { default as downtimeAtom } from './downtimeAtom';
 export { default as refreshIntervalAtom } from './refreshIntervalAtom';
+export { default as statisticsRefreshIntervalAtom } from './statisticsRefreshIntervalAtom';
 export { default as cloudServicesAtom } from './cloudServicesAtom';
 export { default as acknowledgementAtom } from './acknowledgementAtom';
 export { default as resourceStorageOptimizationModeAtom } from './resourceStorageOptimizationMode';
 export { default as platformNameAtom } from './platformNameAtom';
+export { default as userPermissionsAtom } from './userPermissionsAtom';
+
 export { ThemeMode, ListingVariant, DashboardGlobalRole } from './types';
 export {
   platformFeaturesAtom,
@@ -20,6 +23,8 @@ export {
   federatedModulesAtom,
   federatedWidgetsAtom
 } from './federatedModulesAndWidgetsAtoms';
+export { browserLocaleAtom } from './browserLocaleAtom';
+export { isResourceStatusFullSearchEnabledAtom } from './isResourceStatusFullSearchEnabledAtom';
 
 export type {
   User,
@@ -33,5 +38,6 @@ export type {
   DashboardRolesAndPermissions,
   FeatureFlags,
   PlatformFeatures,
-  AdditionalResource
+  AdditionalResource,
+  UserPermissions
 } from './types';
