@@ -1,4 +1,4 @@
-import { Dispatch, SetStateAction } from 'react';
+import type { Dispatch, SetStateAction } from 'react';
 
 export enum ListingVariant {
   compact = 'compact',
@@ -26,7 +26,7 @@ export interface User {
   id?: number;
   isAdmin?: boolean;
   isExportButtonEnabled: boolean;
-  locale: string;
+  locale: string | null;
   name: string;
   themeMode?: ThemeMode;
   timezone: string;
@@ -88,6 +88,7 @@ export interface FeatureFlags {
   adExclusionPeriods?: boolean;
   notification?: boolean;
   vault?: boolean;
+  mapVisxViewer?: boolean;
 }
 
 export interface PlatformFeatures {
@@ -139,3 +140,8 @@ export interface PlatformVersions {
   web: Version;
   widgets: Record<string, Version | null>;
 }
+
+export interface UserPermissions {
+  top_counter: boolean;
+  poller_statistics: boolean;
+}
