@@ -55,6 +55,19 @@ const Template = (args): JSX.Element => {
   return <HeatMap {...args} arrowClassName={classes.arrow} />;
 };
 
+const TileContent = ({ data }: { data: Data }): JSX.Element => (
+  <div
+    style={{
+      alignItems: 'center',
+      display: 'flex',
+      height: '100%',
+      justifyContent: 'center'
+    }}
+  >
+    {data.counter}
+  </div>
+);
+
 export const normal: Story = {
   args: {
     children: TileContent,
