@@ -1,6 +1,10 @@
+import type { ParentSizeProps } from '@visx/responsive/lib/components/ParentSize';
 import { ParentSize } from '../..';
 
 import ResponsiveTimeline from './ResponsiveTimeline';
+import type { TimelineProps } from './models';
+
+interface Props extends ParentSizeProps, TimelineProps {}
 
 const Timeline = ({
   data,
@@ -9,7 +13,7 @@ const Timeline = ({
   TooltipContent,
   tooltipClassName,
   ...rest
-}): JSX.Element => (
+}: Props): JSX.Element => (
   <ParentSize {...rest}>
     {({ width, height }) => (
       <ResponsiveTimeline
@@ -24,5 +28,4 @@ const Timeline = ({
     )}
   </ParentSize>
 );
-
 export default Timeline;
