@@ -3,8 +3,9 @@ import { makeStyles } from 'tss-react/mui';
 export const useStyles = makeStyles()((theme) => ({
   pageLayout: {
     display: 'grid',
-    gridTemplateRows: 'min-content',
-    overflow: 'hidden'
+    gridTemplateRows: 'auto 1fr',
+    overflow: 'hidden',
+    height: '100%'
   },
   pageLayoutActions: {
     '& > span': {
@@ -16,16 +17,19 @@ export const useStyles = makeStyles()((theme) => ({
     },
     display: 'flex',
     justifyContent: 'space-between',
-    paddingBottom: theme.spacing(2.5)
+    paddingBottom: theme.spacing(1.5)
   },
   pageLayoutBody: {
     '&[data-has-background="true"]': {
       backgroundColor: theme.palette.layout.body.background
     },
+    '&[data-has-actions="true"]': {
+      gridTemplateRows: 'min-content auto'
+    },
     display: 'grid',
-    gridTemplateRows: 'min-content',
+    gridTemplateRows: 'auto',
     overflow: 'hidden',
-    padding: theme.spacing(1.5, 3, 5)
+    padding: theme.spacing(0, 3, 1.5)
   },
   pageLayoutHeader: {
     '[data-variant="fixed-header"] &': {
@@ -36,6 +40,6 @@ export const useStyles = makeStyles()((theme) => ({
       top: 0,
       zIndex: `calc(${theme.zIndex.mobileStepper} - 100)`
     },
-    padding: theme.spacing(3, 3, 0)
+    padding: theme.spacing(1, 3, 0)
   }
 }));
