@@ -1,7 +1,7 @@
 <?php
 
 /*
- * Copyright 2005 - 2023 Centreon (https://www.centreon.com/)
+ * Copyright 2005 - 2025 Centreon (https://www.centreon.com/)
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -31,7 +31,7 @@ class Installer extends Widget
     public function install()
     {
         if ($this->informationObj->isInstalled($this->widgetName)) {
-            throw new \Exception('Widget is already installed.');
+            throw new \Exception('Widget "' . $this->widgetName . '" is already installed.');
         }
 
         $id = $this->installConfiguration();
