@@ -31,6 +31,7 @@ class Poller
     public function __construct(
         public readonly int $id,
         public readonly string $name,
+        public readonly ?bool $isCentral = null,
     ) {
     }
 
@@ -43,4 +44,9 @@ class Poller
     {
         return $this->name;
     }
+
+    public function isCentral(): ?bool
+    {
+        return $this->isCentral;
+    }
 }
