@@ -40,7 +40,7 @@ class UserGroup
     public function __construct(
         private int $id,
         private string $name,
-        private string $alias
+        private string $alias,
     ) {
         Assertion::maxLength($name, self::MAX_NAME_LENGTH, 'UserGroup::name');
         Assertion::notEmpty($name, 'UserGroup::name');
