@@ -1,7 +1,7 @@
 <?php
 
 /*
- * Copyright 2005 - 2023 Centreon (https://www.centreon.com/)
+ * Copyright 2005 - 2025 Centreon (https://www.centreon.com/)
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -85,41 +85,33 @@ class AddHostOnPremPresenter extends AbstractPresenter implements AddHostPresent
                         'check_command_args' => $response->checkCommandArgs,
                         'event_handler_command_args' => $response->eventHandlerCommandArgs,
                         'categories' => array_map(
-                            function (array $category) {
-                                return [
-                                    'id' => $category['id'],
-                                    'name' => $category['name'],
-                                ];
-                            },
+                            fn (array $category) => [
+                                'id' => $category['id'],
+                                'name' => $category['name'],
+                            ],
                             $response->categories
                         ),
                         'groups' => array_map(
-                            function (array $group) {
-                                return [
-                                    'id' => $group['id'],
-                                    'name' => $group['name'],
-                                ];
-                            },
+                            fn (array $group) => [
+                                'id' => $group['id'],
+                                'name' => $group['name'],
+                            ],
                             $response->groups
                         ),
                         'templates' => array_map(
-                            function (array $template) {
-                                return [
-                                    'id' => $template['id'],
-                                    'name' => $template['name'],
-                                ];
-                            },
+                            fn (array $template) => [
+                                'id' => $template['id'],
+                                'name' => $template['name'],
+                            ],
                             $response->templates
                         ),
                         'macros' => array_map(
-                            function (array $macro) {
-                                return [
-                                    'name' => $macro['name'],
-                                    'value' => $macro['isPassword'] ? null : $macro['value'],
-                                    'is_password' => $macro['isPassword'],
-                                    'description' => $this->emptyStringAsNull($macro['description']),
-                                ];
-                            },
+                            fn (array $macro) => [
+                                'name' => $macro['name'],
+                                'value' => $macro['isPassword'] ? null : $macro['value'],
+                                'is_password' => $macro['isPassword'],
+                                'description' => $this->emptyStringAsNull($macro['description']),
+                            ],
                             $response->macros
                         ),
                         'add_inherited_contact_group' => $response->addInheritedContactGroup,
