@@ -23,15 +23,23 @@ declare(strict_types=1);
 
 namespace Core\Media\Infrastructure\API\FindMedias;
 
+use Centreon\Domain\Log\Logger;
 use Centreon\Domain\RequestParameters\Interfaces\RequestParametersInterface;
 use Core\Application\Common\UseCase\AbstractPresenter;
+use Core\Application\Common\UseCase\ErrorResponse;
+use Core\Application\Common\UseCase\ForbiddenResponse;
 use Core\Application\Common\UseCase\ResponseStatusInterface;
+use Core\Common\Infrastructure\ExceptionLogger\ExceptionLogger;
+use Core\Infrastructure\Common\Api\HttpUrlTrait;
 use Core\Infrastructure\Common\Presenter\PresenterFormatterInterface;
 use Core\Media\Application\UseCase\FindMedias\FindMediasPresenterInterface;
 use Core\Media\Application\UseCase\FindMedias\FindMediasResponse;
 
 class FindMediasPresenter extends AbstractPresenter implements FindMediasPresenterInterface
 {
+    use HttpUrlTrait;
+    private const IMG_FOLDER_PATH = '/img/media/';
+
     public function __construct(
         private readonly RequestParametersInterface $requestParameters,
         protected PresenterFormatterInterface $presenterFormatter,
@@ -42,21 +50,29 @@ class FindMediasPresenter extends AbstractPresenter implements FindMediasPresent
     public function presentResponse(FindMediasResponse|ResponseStatusInterface $response): void
     {
         if ($response instanceof ResponseStatusInterface) {
-            $this->setResponseStatus($response);
-        } else {
-            $result = [];
-            foreach ($response->medias as $dto) {
-                $result[] = [
-                    'id' => $dto->id,
-                    'filename' => $dto->filename,
-                    'directory' => $dto->directory,
-                    'md5' => $dto->md5,
-                ];
+            if ($response instanceof ErrorResponse && ! is_null($response->getException())) {
+                ExceptionLogger::create()->log($response->getException(), $response->getContext());
+            } elseif ($response instanceof ForbiddenResponse) {
+                Logger::create()->warning("User doesn't have sufficient rights to list media", $response->getContext());
             }
-            $this->present([
-                'result' => $result,
-                'meta' => $this->requestParameters->toArray(),
-            ]);
+            $this->setResponseStatus($response);
+
+            return;
         }
+
+        $result = [];
+        foreach ($response->medias as $dto) {
+            $result[] = [
+                'id' => $dto->id,
+                'name' => $dto->filename,
+                'directory' => $dto->directory,
+                'md5' => $dto->md5,
+                'url' => $this->getBaseUri() . self::IMG_FOLDER_PATH . $dto->directory . '/' . $dto->filename,
+            ];
+        }
+        $this->present([
+            'result' => $result,
+            'meta' => $this->requestParameters->toArray(),
+        ]);
     }
 }
