@@ -109,7 +109,7 @@ class DbReadResourceRepository extends DatabaseRepository implements ReadResourc
         SqlRequestParametersTranslator $sqlRequestTranslator,
         \Traversable $resourceTypes,
         private readonly \Traversable $resourceACLProviders,
-        \Traversable $extraDataProviders
+        \Traversable $extraDataProviders,
     ) {
         parent::__construct($db, $queryBuilder);
         $this->sqlRequestTranslator = $sqlRequestTranslator;
@@ -363,7 +363,7 @@ class DbReadResourceRepository extends DatabaseRepository implements ReadResourc
     public function iterateResourcesByAccessGroupIds(
         ResourceFilter $filter,
         array $accessGroupIds,
-        int $maxResults = 0
+        int $maxResults = 0,
     ): \Traversable {
         try {
             $this->resources = [];
@@ -438,7 +438,7 @@ class DbReadResourceRepository extends DatabaseRepository implements ReadResourc
     public function countResourcesByFilterAndAccessGroupIds(
         ResourceFilter $filter,
         bool $allPages,
-        array $accessGroupIds
+        array $accessGroupIds,
     ): int {
         // if $allPages is set to true, we don't use pagination and limit because count all resources
         if ($allPages) {
@@ -529,7 +529,7 @@ class DbReadResourceRepository extends DatabaseRepository implements ReadResourc
         ResourceFilter $filter,
         QueryParameters $queryParametersFromRequestParameter,
         array $accessGroupIds = [],
-        bool $onlyCount = false
+        bool $onlyCount = false,
     ): string {
         $this->sqlRequestTranslator->setConcordanceArray($this->resourceConcordances);
 
@@ -725,7 +725,7 @@ class DbReadResourceRepository extends DatabaseRepository implements ReadResourc
      */
     private function createQueryHeaders(
         ResourceFilter $filter,
-        QueryParameters $queryParametersFromRequestParameter
+        QueryParameters $queryParametersFromRequestParameter,
     ): string {
         $headers = '';
         $nextHeaders = function () use (&$headers): void {
@@ -921,7 +921,7 @@ class DbReadResourceRepository extends DatabaseRepository implements ReadResourc
     private function count(
         string $query,
         QueryParameters $queryParametersFromRequestParameters,
-        bool $withFilter = true
+        bool $withFilter = true,
     ): int {
         $queryResources = $this->translateDbName($query);
 
@@ -950,7 +950,7 @@ class DbReadResourceRepository extends DatabaseRepository implements ReadResourc
      */
     private function iterate(
         string $query,
-        QueryParameters $queryParametersFromRequestParameters
+        QueryParameters $queryParametersFromRequestParameters,
     ): \Traversable {
         $queryResources = $this->translateDbName($query);
         $queryParametersFromSearchValues = SearchRequestParametersTransformer::reverseToQueryParameters(
@@ -1007,7 +1007,7 @@ class DbReadResourceRepository extends DatabaseRepository implements ReadResourc
     {
         $resourcesWithIcons = array_filter(
             $this->resources,
-            static fn (ResourceEntity $resource): bool => null !== $resource->getIcon()
+            static fn (ResourceEntity $resource): bool => $resource->getIcon() !== null
         );
 
         return array_map(
@@ -1023,7 +1023,7 @@ class DbReadResourceRepository extends DatabaseRepository implements ReadResourc
     {
         $resourcesWithSeverities = array_filter(
             $this->resources,
-            static fn (ResourceEntity $resource): bool => null !== $resource->getSeverity()
+            static fn (ResourceEntity $resource): bool => $resource->getSeverity() !== null
         );
 
         return array_map(
@@ -1113,7 +1113,7 @@ class DbReadResourceRepository extends DatabaseRepository implements ReadResourc
      */
     private function addSeveritySubRequest(
         ResourceFilter $filter,
-        QueryParameters $queryParametersFromRequestParameter
+        QueryParameters $queryParametersFromRequestParameter,
     ): string {
         $subRequest = '';
         $filteredNames = [];
@@ -1175,7 +1175,7 @@ class DbReadResourceRepository extends DatabaseRepository implements ReadResourc
      */
     private function addResourceParentIdSubRequest(
         ResourceFilter $filter,
-        QueryParameters $queryParametersFromRequestParameter
+        QueryParameters $queryParametersFromRequestParameter,
     ): string {
         $subRequest = '';
         $filteredParentIds = [];
@@ -1348,7 +1348,7 @@ class DbReadResourceRepository extends DatabaseRepository implements ReadResourc
      */
     private function addMonitoringServerSubRequest(
         ResourceFilter $filter,
-        QueryParameters $queryParametersFromRequestParameter
+        QueryParameters $queryParametersFromRequestParameter,
     ): string {
         $subRequest = '';
         if (! empty($filter->getMonitoringServerNames())) {
