@@ -36,6 +36,7 @@ use Core\Security\ProviderConfiguration\Domain\Model\Provider;
 use Core\Security\Token\Application\Exception\TokenException;
 use Core\Security\Token\Application\Repository\ReadTokenRepositoryInterface;
 use Core\Security\Token\Application\Repository\WriteTokenRepositoryInterface;
+use Core\Security\Token\Domain\Model\NewApiToken;
 use Core\Security\Token\Domain\Model\TokenFactory;
 
 final class AddToken
@@ -106,6 +107,18 @@ final class AddToken
 
         $this->writeTokenRepository->add($newToken);
 
+        $this->info(
+            'Add token succeeded',
+            [
+                'event' => 'Token creation',
+                'datetime' => (new \DateTimeImmutable())->format('Y-m-d H:i:s'),
+                'creator_id' => $newToken->getCreatorId(),
+                'user_id' => $newToken instanceof NewApiToken ? $newToken->getUserId() : null,
+                'token_type' => $newToken->getType()->name,
+                'token_name' => $newToken->getName(),
+            ]
+        );
+
         return $newToken->getToken();
     }
 
