@@ -1,7 +1,7 @@
 <?php
 
 /*
- * Copyright 2005 - 2023 Centreon (https://www.centreon.com/)
+ * Copyright 2005 - 2025 Centreon (https://www.centreon.com/)
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -19,7 +19,7 @@
  *
  */
 
-declare(strict_types = 1);
+declare(strict_types=1);
 
 namespace Core\Security\Vault\Application\UseCase\MigrateAllCredentials;
 
@@ -311,8 +311,7 @@ final class MigrateAllCredentials
         foreach ($hostTemplates as $hostTemplate) {
             if (
                 $hostTemplate->getSnmpCommunity() === ''
-                || str_starts_with($hostTemplate->getSnmpCommunity(), VaultConfiguration::VAULT_PATH_PATTERN))
-            {
+                || str_starts_with($hostTemplate->getSnmpCommunity(), VaultConfiguration::VAULT_PATH_PATTERN)) {
                 continue;
             }
             $credential = new CredentialDto();
@@ -416,7 +415,7 @@ final class MigrateAllCredentials
             $knowledgeBasePasswordOption === null
             || $knowledgeBasePasswordOption->getValue() === null
             || str_starts_with($knowledgeBasePasswordOption->getValue(), VaultConfiguration::VAULT_PATH_PATTERN)
-        ){
+        ) {
             return $credentials;
         }
 
@@ -505,7 +504,7 @@ final class MigrateAllCredentials
                                 && isset($groupedParams['value'])
                                 && $groupedParams['value'] !== ''
                                 && ! str_starts_with((string) $groupedParams['value'], 'secret::')
-                                ) {
+                            ) {
                                 /** @var array{type:string,name:string,value:string|int} $groupedParams */
                                 $credential = new CredentialDto();
                                 $credential->resourceId = $brokerId;
