@@ -23,11 +23,17 @@ declare(strict_types=1);
 
 namespace Core\Service\Infrastructure\Repository;
 
+use Adaptation\Database\Connection\Collection\QueryParameters;
+use Adaptation\Database\Connection\Exception\ConnectionException;
+use Adaptation\Database\Connection\ValueObject\QueryParameter;
 use Centreon\Domain\RequestParameters\Interfaces\RequestParametersInterface;
 use Centreon\Infrastructure\DatabaseConnection;
 use Centreon\Infrastructure\RequestParameters\Interfaces\NormalizerInterface;
 use Centreon\Infrastructure\RequestParameters\RequestParametersTranslatorException;
 use Centreon\Infrastructure\RequestParameters\SqlRequestParametersTranslator;
+use Core\Common\Domain\Exception\CollectionException;
+use Core\Common\Domain\Exception\RepositoryException;
+use Core\Common\Domain\Exception\ValueObjectException;
 use Core\Common\Infrastructure\Repository\AbstractRepositoryRDB;
 use Core\Common\Infrastructure\Repository\SqlMultipleBindTrait;
 use Core\Service\Application\Repository\ReadRealTimeServiceRepositoryInterface;
@@ -86,7 +92,7 @@ class DbReadRealTimeServiceRepository extends AbstractRepositoryRDB implements R
      */
     public function findStatusesByRequestParametersAndAccessGroupIds(
         RequestParametersInterface $requestParameters,
-        array $accessGroupIds
+        array $accessGroupIds,
     ): ServiceStatusesCount {
         if ($accessGroupIds === []) {
             $this->createServiceStatusesCountFromRecord([]);
@@ -163,7 +169,7 @@ class DbReadRealTimeServiceRepository extends AbstractRepositoryRDB implements R
      */
     public function findUniqueServiceNamesByRequestParametersAndAccessGroupIds(
         RequestParametersInterface $requestParameters,
-        array $accessGroupIds
+        array $accessGroupIds,
     ): array {
         if ($accessGroupIds === []) {
             return [];
@@ -200,6 +206,76 @@ class DbReadRealTimeServiceRepository extends AbstractRepositoryRDB implements R
         return $serviceNames;
     }
 
+    /**
+     * @inheritDoc
+     */
+    public function exists(int $serviceId, int $hostId): bool
+    {
+        $query = <<<'SQL'
+                SELECT 1
+                FROM `:dbstg`.services
+                WHERE service_id = :serviceId
+                    AND host_id = :hostId
+            SQL;
+
+        try {
+            $raw = $this->db->fetchOne(
+                $this->translateDbName($query),
+                QueryParameters::create([
+                    QueryParameter::int('serviceId', $serviceId),
+                    QueryParameter::int('hostId', $hostId),
+                ])
+            );
+
+            return (bool) $raw;
+        } catch (ValueObjectException|CollectionException|ConnectionException $e) {
+            throw new RepositoryException(
+                sprintf(
+                    'Error checking existence of service %d on host %d',
+                    $serviceId,
+                    $hostId
+                ),
+                [
+                    'serviceId' => $serviceId,
+                    'hostId' => $hostId,
+                ],
+                $e
+            );
+        }
+    }
+
+    /**
+     * @inheritDoc
+     */
+    public function existsByDescription(int $metaServiceId): array|false
+    {
+        $query = <<<'SQL'
+                SELECT service_id, host_id
+                FROM `:dbstg`.services s
+                WHERE s.description = :metaId
+            SQL;
+
+        try {
+            return $this->db->fetchAssociative(
+                $this->translateDbName($query),
+                QueryParameters::create([
+                    QueryParameter::string('metaId', "meta_{$metaServiceId}"),
+                ])
+            );
+        } catch (ValueObjectException|CollectionException|ConnectionException $e) {
+            throw new RepositoryException(
+                sprintf(
+                    'Error checking existence of meta service as service with description: meta_%d',
+                    $metaServiceId
+                ),
+                [
+                    'metaServiceId' => $metaServiceId,
+                ],
+                $e
+            );
+        }
+    }
+
     /**
      * @param SqlRequestParametersTranslator $sqlTranslator
      * @param bool $calculateNumberOfRows
@@ -212,7 +288,7 @@ class DbReadRealTimeServiceRepository extends AbstractRepositoryRDB implements R
         SqlRequestParametersTranslator $sqlTranslator,
         bool $calculateNumberOfRows,
         array $accessGroupIds = [],
-        string $aclBindQuery = ''
+        string $aclBindQuery = '',
     ): string {
         $search = $sqlTranslator->translateSearchParameterToSql();
         $typeSearch = $search !== null ? ' AND services.type = 0 ' : ' WHERE services.type = 0 ';
@@ -268,6 +344,7 @@ class DbReadRealTimeServiceRepository extends AbstractRepositoryRDB implements R
             {$search}
             {$typeSearch}
             {$aclSearch}
+                AND services.enabled = 1
             GROUP BY services.name
             {$sort}
             {$limit}
@@ -317,7 +394,7 @@ class DbReadRealTimeServiceRepository extends AbstractRepositoryRDB implements R
      * @return SqlRequestParametersTranslator
      */
     private function prepareSqlRequestParametersTranslator(
-        RequestParametersInterface $requestParameters
+        RequestParametersInterface $requestParameters,
     ): SqlRequestParametersTranslator {
         $sqlTranslator = new SqlRequestParametersTranslator($requestParameters);
         $sqlTranslator->setConcordanceArray([
@@ -341,7 +418,7 @@ class DbReadRealTimeServiceRepository extends AbstractRepositoryRDB implements R
                 /**
                  * @inheritDoc
                  */
-                public function normalize($valueToNormalize)
+                public function normalize($valueToNormalize): int
                 {
                     switch (mb_strtoupper((string) $valueToNormalize)) {
                         case 'OK':
