@@ -303,7 +303,8 @@ final class PartialUpdateServiceTemplateController extends AbstractController
         if (array_key_exists('service_groups', $request)) {
             $serviceTemplate->serviceGroups = array_map(
                 fn (array $serviceGroup): ServiceGroupDto => new ServiceGroupDto(
-                    $serviceGroup['host_template_id'], $serviceGroup['service_group_id']
+                    $serviceGroup['host_template_id'],
+                    $serviceGroup['service_group_id']
                 ),
                 $request['service_groups']
             );
