@@ -1,15 +1,10 @@
 import { Then, When } from '@badeball/cypress-cucumber-preprocessor';
 
-import { PAGES } from 'e2e/fixtures/shared/constants/pages';
 import {
   checkHostsAreMonitored,
   checkServicesAreMonitored
 } from '../../../../commons';
-import {
-  reloadWebServer,
-  replaceCustomUri,
-  updateWebServerConfig
-} from '../common';
+import { reloadWebServer, updateWebServerConfig } from '../common';
 
 const service = 'Ping';
 const host = 'Centreon-Server';
@@ -88,7 +83,11 @@ Then(
 
     cy.contains(host).parent().get('.MuiChip-root').should('contain', 'h');
 
-    cy.visit(replaceCustomUri(PAGES.configuration.hostsLegacy, '/monitor'));
+    cy.navigateTo({
+      page: 'Hosts',
+      rootItemNumber: 3,
+      subMenu: 'Hosts'
+    });
 
     cy.wait('@getTimeZone').then(() => {
       cy.getIframeBody()
@@ -104,9 +103,11 @@ Then(
         .should('be.gte', 21);
     });
 
-    cy.visit(
-      replaceCustomUri(PAGES.configuration.servicesByHostLegacy, '/monitor')
-    );
+    cy.navigateTo({
+      page: 'Services by host',
+      rootItemNumber: 3,
+      subMenu: 'Services'
+    });
 
     cy.wait('@getTimeZone').then(() => {
       cy.getIframeBody()
@@ -141,7 +142,10 @@ Then(
       }
     ]);
 
-    cy.visit(replaceCustomUri(PAGES.monitoring.resourcesStatus, '/monitor'));
+    cy.navigateTo({
+      page: 'Resources Status',
+      rootItemNumber: 1
+    });
 
     cy.get('header').parent().children().eq(1).contains('OK').should('exist');
 
