@@ -1,12 +1,11 @@
 import { Given, Then, When } from '@badeball/cypress-cucumber-preprocessor';
-import { PAGES } from 'e2e/fixtures/shared/constants/pages';
 
 beforeEach(() => {
   cy.startContainers();
   cy.intercept({
     method: 'GET',
     url: '/centreon/include/common/userTimezone.php'
-  }).as('getUserTimezone');
+  }).as('getTimeZone');
   cy.intercept({
     method: 'GET',
     url: '/centreon/api/internal.php?object=centreon_topology&action=navigationList'
@@ -33,7 +32,11 @@ When('a service is configured', () => {
 });
 
 When('the user changes the properties of a service', () => {
-  cy.visit(PAGES.configuration.servicesByHostLegacy);
+  cy.navigateTo({
+    page: 'Services by host',
+    rootItemNumber: 3,
+    subMenu: 'Services'
+  });
 
   cy.enterIframe('iframe#main-content')
     .find('table.ListTable')
@@ -106,7 +109,11 @@ Then('the properties are updated', () => {
 });
 
 When('the user duplicates a service', () => {
-  cy.visit(PAGES.configuration.servicesByHostLegacy);
+  cy.navigateTo({
+    page: 'Services by host',
+    rootItemNumber: 3,
+    subMenu: 'Services'
+  });
   cy.waitForElementInIframe('#main-content', 'input[name="searchH"]');
   cy.getIframeBody().find('input[name="searchH"]').clear().type('host_1');
   cy.getIframeBody().find('input[name="Search"].btc.bt_success').click();
@@ -141,7 +148,11 @@ Then('the new service has the same properties', () => {
 });
 
 When('the user deletes a service', () => {
-  cy.visit(PAGES.configuration.servicesByHostLegacy);
+  cy.navigateTo({
+    page: 'Services by host',
+    rootItemNumber: 3,
+    subMenu: 'Services'
+  });
   cy.enterIframe('iframe#main-content')
     .find('table tbody')
     .find('tr.list_one')
@@ -174,10 +185,7 @@ When('the user deletes a service', () => {
 });
 
 Then('the deleted service is not displayed in the service list', () => {
-  cy.enterIframe('iframe#main-content')
-    .find('table.ListTable tbody')
-    .contains('test')
-    .should('not.exist');
+  cy.wait('@getTimeZone');
 });
 
 afterEach(() => {
