@@ -1,8 +1,7 @@
 import { Given, Then, When } from '@badeball/cypress-cucumber-preprocessor';
 
-import { PAGES } from 'e2e/fixtures/shared/constants/pages';
 import data from '../../../fixtures/snmp-traps/snmp-trap.json';
-import { createOrUpdateTrapGroup } from '../common';
+import { CreateOrUpdateTrapGroup } from '../common';
 
 const checkFirstTrapGroupFromListing = () => {
   cy.waitForElementInIframe('#main-content', 'a[href*="id=1"]');
@@ -37,10 +36,14 @@ Given('an admin user is logged in a Centreon server', () => {
 });
 
 Given('a trap group is configured', () => {
-  cy.visit(PAGES.configuration.snmpTrapsGroupsLegacy);
+  cy.navigateTo({
+    page: 'Group',
+    rootItemNumber: 3,
+    subMenu: 'SNMP Traps'
+  });
   cy.wait('@getTimeZone');
   cy.getIframeBody().contains('a', 'Add').click();
-  createOrUpdateTrapGroup(data.snmpGroup1);
+  CreateOrUpdateTrapGroup(data.snmpGroup1);
   cy.wait('@getTimeZone');
   cy.exportConfig();
 });
@@ -48,7 +51,7 @@ Given('a trap group is configured', () => {
 When('the user changes the properties of a trap group', () => {
   cy.waitForElementInIframe('#main-content', 'a[href*="id=1"]');
   cy.getIframeBody().contains(data.snmpGroup1.name).click();
-  createOrUpdateTrapGroup(data.snmpGroup2);
+  CreateOrUpdateTrapGroup(data.snmpGroup2);
   cy.wait('@getTimeZone');
   cy.exportConfig();
 });
