@@ -189,13 +189,15 @@ it(
     AssertionException::notEmptyString('Host::name')->getMessage()
 );
 it(
-    'should throw an exception when host name is set to an empty string', function (): void {
+    'should throw an exception when host name is set to an empty string',
+    function (): void {
         $host = ($this->createHost)();
         $host->setName('   ');
-    })->throws(
-        InvalidArgumentException::class,
-        AssertionException::notEmptyString('Host::name')->getMessage()
-    );
+    }
+)->throws(
+    InvalidArgumentException::class,
+    AssertionException::notEmptyString('Host::name')->getMessage()
+);
 
 it(
     'should throw an exception when host address does not respect format',
@@ -205,7 +207,8 @@ it(
     AssertionException::ipOrDomain('hello world', 'Host::address')->getMessage()
 );
 it(
-    'should throw an exception when host address does not respect format in setter', function (): void {
+    'should throw an exception when host address does not respect format in setter',
+    function (): void {
         $host = ($this->createHost)();
         $host->setAddress('hello world');
     }
