@@ -1,4 +1,5 @@
 <?php
+
 /*
  * Copyright 2005 - 2025 Centreon (https://www.centreon.com/)
  *
@@ -6,7 +7,7 @@
  * you may not use this file except in compliance with the License.
  * You may obtain a copy of the License at
  *
- * http://www.apache.org/licenses/LICENSE-2.0
+ * https://www.apache.org/licenses/LICENSE-2.0
  *
  * Unless required by applicable law or agreed to in writing, software
  * distributed under the License is distributed on an "AS IS" BASIS,
@@ -25,7 +26,7 @@ namespace Tests\Core\Resources\Infrastructure\API\ExportResources;
 use Core\Resources\Infrastructure\API\ExportResources\ExportResourcesInput;
 use Symfony\Component\Validator\Validation;
 
-beforeEach(function () {
+beforeEach(function (): void {
     $this->validator = Validation::createValidatorBuilder()
         ->enableAttributeMapping()
         ->getValidator();
@@ -33,7 +34,7 @@ beforeEach(function () {
 
 // format parameter
 
-it('test export resources input validation with no format', function () {
+it('test export resources input validation with no format', function (): void {
     $input = new ExportResourcesInput(
         null,
         false,
@@ -49,7 +50,7 @@ it('test export resources input validation with no format', function () {
         ->and($errors[0]->getMessage())->toBe('format parameter is required');
 });
 
-it('test export resources input validation with an empty format', function () {
+it('test export resources input validation with an empty format', function (): void {
     $input = new ExportResourcesInput(
         '',
         false,
@@ -66,7 +67,7 @@ it('test export resources input validation with an empty format', function () {
         ->and($errors[1]->getMessage())->toBe('format parameter must be one of the following: "csv"');
 });
 
-it('test export resources input validation with an invalid type for format', function () {
+it('test export resources input validation with an invalid type for format', function (): void {
     $input = new ExportResourcesInput(
         0,
         false,
@@ -82,7 +83,7 @@ it('test export resources input validation with an invalid type for format', fun
         ->and($errors[0]->getMessage())->toBe('format parameter must be one of the following: "csv"');
 });
 
-it('test export resources input validation with an invalid value for format', function () {
+it('test export resources input validation with an invalid value for format', function (): void {
     $input = new ExportResourcesInput(
         'pdf',
         false,
@@ -98,7 +99,7 @@ it('test export resources input validation with an invalid value for format', fu
         ->and($errors[0]->getMessage())->toBe('format parameter must be one of the following: "csv"');
 });
 
-it('test export resources input validation with a valid format', function () {
+it('test export resources input validation with a valid format', function (): void {
     $input = new ExportResourcesInput(
         'csv',
         false,
@@ -115,28 +116,28 @@ it('test export resources input validation with a valid format', function () {
 
 // sort_by parameter
 
-it('test export resources input validation with no sort_by', function () {
+it('test export resources input validation with no sort_by', function (): void {
     $input = new ExportResourcesInput('csv', false, null, null, 1, 100, null, '{"$and":[]}');
     $errors = $this->validator->validate($input);
     expect($errors)->toHaveCount(1)
         ->and($errors[0]->getMessage())->toBe('sort_by parameter is required');
 });
 
-it('test export resources input validation with an empty sort_by', function () {
+it('test export resources input validation with an empty sort_by', function (): void {
     $input = new ExportResourcesInput('csv', false, null, null, 1, 100, '', '{"$and":[]}');
     $errors = $this->validator->validate($input);
     expect($errors)->toHaveCount(1)
         ->and($errors[0]->getMessage())->toBe('sort_by parameter is required');
 });
 
-it('test export resources input validation with an invalid value for sort_by', function () {
+it('test export resources input validation with an invalid value for sort_by', function (): void {
     $input = new ExportResourcesInput('csv', false, null, null, 1, 100, 'toto', '{"$and":[]}');
     $errors = $this->validator->validate($input);
     expect($errors)->toHaveCount(1)
         ->and($errors[0]->getMessage())->toBe('sort_by parameter must be a valid JSON');
 });
 
-it('test export resources input validation with sort_by with an invalid json', function () {
+it('test export resources input validation with sort_by with an invalid json', function (): void {
     $input = new ExportResourcesInput(
         'csv',
         false,
@@ -152,7 +153,7 @@ it('test export resources input validation with sort_by with an invalid json', f
         ->and($errors[0]->getMessage())->toBe('sort_by parameter must be a valid JSON');
 });
 
-it('test export resources input validation with a valid json for sort_by', function () {
+it('test export resources input validation with a valid json for sort_by', function (): void {
     $input = new ExportResourcesInput(
         'csv',
         false,
@@ -169,7 +170,7 @@ it('test export resources input validation with a valid json for sort_by', funct
 
 // search parameter
 
-it('test export resources input validation with no search', function () {
+it('test export resources input validation with no search', function (): void {
     $input = new ExportResourcesInput(
         'csv',
         false,
@@ -185,7 +186,7 @@ it('test export resources input validation with no search', function () {
         ->and($errors[0]->getMessage())->toBe('search parameter is required');
 });
 
-it('test export resources input validation with an empty search', function () {
+it('test export resources input validation with an empty search', function (): void {
     $input = new ExportResourcesInput(
         'csv',
         false,
@@ -201,7 +202,7 @@ it('test export resources input validation with an empty search', function () {
         ->and($errors[0]->getMessage())->toBe('search parameter is required');
 });
 
-it('test export resources input validation with search with an invalid value', function () {
+it('test export resources input validation with search with an invalid value', function (): void {
     $input = new ExportResourcesInput(
         'csv',
         false,
@@ -217,7 +218,7 @@ it('test export resources input validation with search with an invalid value', f
         ->and($errors[0]->getMessage())->toBe('search parameter must be a valid JSON');
 });
 
-it('test export resources input validation with search with an invalid json', function () {
+it('test export resources input validation with search with an invalid json', function (): void {
     $input = new ExportResourcesInput(
         'csv',
         false,
@@ -233,7 +234,7 @@ it('test export resources input validation with search with an invalid json', fu
         ->and($errors[0]->getMessage())->toBe('search parameter must be a valid JSON');
 });
 
-it('test export resources input validation with search with a valid json', function () {
+it('test export resources input validation with search with a valid json', function (): void {
     $input = new ExportResourcesInput(
         'csv',
         false,
@@ -250,7 +251,7 @@ it('test export resources input validation with search with a valid json', funct
 
 // all_pages parameter
 
-it('test export resources input validation with no all_pages', function () {
+it('test export resources input validation with no all_pages', function (): void {
     $input = new ExportResourcesInput(
         'csv',
         null,
@@ -266,7 +267,7 @@ it('test export resources input validation with no all_pages', function () {
         ->and($errors[0]->getMessage())->toBe('all_pages parameter is required');
 });
 
-it('test export resources input validation with an empty all_pages', function () {
+it('test export resources input validation with an empty all_pages', function (): void {
     $input = new ExportResourcesInput(
         'csv',
         '',
@@ -282,7 +283,7 @@ it('test export resources input validation with an empty all_pages', function ()
         ->and($errors[0]->getMessage())->toBe('all_pages parameter must be a boolean');
 });
 
-it('test export resources input validation with an invalid type for all_pages', function () {
+it('test export resources input validation with an invalid type for all_pages', function (): void {
     $input = new ExportResourcesInput(
         'csv',
         'toto',
@@ -298,7 +299,7 @@ it('test export resources input validation with an invalid type for all_pages',
         ->and($errors[0]->getMessage())->toBe('all_pages parameter must be a boolean');
 });
 
-it('test export resources input validation with all_pages equals to false without page and limit', function () {
+it('test export resources input validation with all_pages equals to false without page and limit', function (): void {
     $input = new ExportResourcesInput(
         'csv',
         false,
@@ -315,7 +316,7 @@ it('test export resources input validation with all_pages equals to false withou
         ->and($errors[1]->getMessage())->toBe('limit parameter is required when all_pages is false');
 });
 
-it('test export resources input validation with all_pages equals to false with page and without limit', function () {
+it('test export resources input validation with all_pages equals to false with page and without limit', function (): void {
     $input = new ExportResourcesInput(
         'csv',
         false,
@@ -331,7 +332,7 @@ it('test export resources input validation with all_pages equals to false with p
         ->and($errors[0]->getMessage())->toBe('limit parameter is required when all_pages is false');
 });
 
-it('test export resources input validation with all_pages equals to false with limit and without page', function () {
+it('test export resources input validation with all_pages equals to false with limit and without page', function (): void {
     $input = new ExportResourcesInput(
         'csv',
         false,
@@ -349,7 +350,7 @@ it('test export resources input validation with all_pages equals to false with l
 
 it(
     'test export resources input validation with all_pages equals to false with limit and page with an invalid format for limit',
-    function () {
+    function (): void {
         $input = new ExportResourcesInput(
             'csv',
             false,
@@ -368,7 +369,7 @@ it(
 
 it(
     'test export resources input validation with all_pages equals to false with limit and page with an invalid format for page',
-    function () {
+    function (): void {
         $input = new ExportResourcesInput(
             'csv',
             false,
@@ -387,7 +388,7 @@ it(
 
 it(
     'test export resources input validation with all_pages equals to false with limit and page = 0',
-    function () {
+    function (): void {
         $input = new ExportResourcesInput(
             'csv',
             false,
@@ -404,7 +405,7 @@ it(
     }
 );
 
-it('test export resources input validation with all_pages equals to false with valid limit and page', function () {
+it('test export resources input validation with all_pages equals to false with valid limit and page', function (): void {
     $input = new ExportResourcesInput(
         'csv',
         false,
@@ -421,7 +422,7 @@ it('test export resources input validation with all_pages equals to false with v
 
 it(
     'test export resources input validation with all_pages equals to true without pagination and without max_lines',
-    function () {
+    function (): void {
         $input = new ExportResourcesInput(
             'csv',
             true,
@@ -440,7 +441,7 @@ it(
 
 it(
     'test export resources input validation with all_pages equals to true without pagination and with an invalid max_lines',
-    function () {
+    function (): void {
         $input = new ExportResourcesInput(
             'csv',
             true,
@@ -459,7 +460,7 @@ it(
 
 it(
     'test export resources input validation with all_pages equals to true without pagination and with a max_lines greather than 10000',
-    function () {
+    function (): void {
         $input = new ExportResourcesInput(
             'csv',
             true,
@@ -478,7 +479,7 @@ it(
 
 it(
     'test export resources input validation with all_pages equals to true without pagination and with a valid max_lines',
-    function () {
+    function (): void {
         $input = new ExportResourcesInput(
             'csv',
             true,
@@ -496,7 +497,7 @@ it(
 
 it(
     'test export resources input validation with all_pages equals to true with pagination (should be ignored) and with a valid max_lines',
-    function () {
+    function (): void {
         $input = new ExportResourcesInput(
             'csv',
             true,
@@ -514,7 +515,7 @@ it(
 
 // columns parameter
 
-it('test export resources input validation with no columns', function () {
+it('test export resources input validation with no columns', function (): void {
     $input = new ExportResourcesInput(
         'csv',
         false,
@@ -529,7 +530,7 @@ it('test export resources input validation with no columns', function () {
     expect($errors)->toHaveCount(0);
 });
 
-it('test export resources input validation with an empty columns', function () {
+it('test export resources input validation with an empty columns', function (): void {
     $input = new ExportResourcesInput(
         'csv',
         false,
@@ -546,7 +547,7 @@ it('test export resources input validation with an empty columns', function () {
         ->and($errors[1]->getMessage())->toBe('This value should be of type iterable.');
 });
 
-it('test export resources input validation with an invalid columns', function () {
+it('test export resources input validation with an invalid columns', function (): void {
     $input = new ExportResourcesInput(
         'csv',
         false,
@@ -563,7 +564,7 @@ it('test export resources input validation with an invalid columns', function ()
         ->and($errors[1]->getMessage())->toBe('This value should be of type iterable.');
 });
 
-it('test export resources input validation with columns with an empty value', function () {
+it('test export resources input validation with columns with an empty value', function (): void {
     $input = new ExportResourcesInput(
         'csv',
         false,
@@ -582,7 +583,7 @@ it('test export resources input validation with columns with an empty value', fu
         );
 });
 
-it('test export resources input validation with columns with an invalid value', function () {
+it('test export resources input validation with columns with an invalid value', function (): void {
     $input = new ExportResourcesInput(
         'csv',
         false,
@@ -600,7 +601,7 @@ it('test export resources input validation with columns with an invalid value',
         );
 });
 
-it('test export resources input validation with columns with a valid value', function () {
+it('test export resources input validation with columns with a valid value', function (): void {
     $input = new ExportResourcesInput(
         'csv',
         false,
@@ -614,4 +615,3 @@ it('test export resources input validation with columns with a valid value', fun
     $errors = $this->validator->validate($input);
     expect($errors)->toHaveCount(0);
 });
-
