@@ -490,7 +490,7 @@ abstract class CentreonObject
         $query = 'SELECT LAST_INSERT_ID() as action_log_id';
         $stmt = $dbstorage->query($query);
         $row = $stmt->fetch();
-        if (false === $row) {
+        if ($row === false) {
             throw new CentreonClapiException('Error while inserting log action');
         }
         $stmt->closeCursor();
