@@ -1,6 +1,5 @@
-import initialize from './initialize';
-
 import { labelPortExpectedAtMost } from '../../VaultConfiguration/translatedLabels';
+import initialize from './initialize';
 
 import {
   labelAction,
@@ -11,13 +10,13 @@ import {
   labelAgentConfigurationUpdated,
   labelAgentType,
   labelAgentsConfigurations,
+  labelByPoller,
   labelCACommonName,
-  labelCMAauthenticationToken,
   labelCaCertificate,
   labelCancel,
   labelClear,
   labelConfigurationServer,
-  labelConnectionInitiatedByPoller,
+  labelConnectionInitiated,
   labelDNSIP,
   labelDelete,
   labelDeleteAgent,
@@ -38,7 +37,6 @@ import {
   labelRelativePathAreNotAllowed,
   labelRequired,
   labelSave,
-  labelSearch,
   labelSelectExistingCMAToken,
   labelSelectExistingCMATokens,
   labelSelectHost,
@@ -66,7 +64,7 @@ describe('Agent configurations', () => {
 
     cy.waitForRequest('@getAgentConfigurations').then(({ request }) => {
       expect(decodeURIComponent(request.url.search)).equals(
-        '?page=1&limit=10&sort_by={"name":"asc"}&search={"$and":[]}'
+        '?page=1&limit=10&sort_by={"name":"asc"}&search={"$or":[{"name":{"$rg":""}}]}'
       );
     });
 
@@ -90,7 +88,7 @@ describe('Agent configurations', () => {
 
     cy.waitForRequest('@getAgentConfigurations').then(({ request }) => {
       expect(decodeURIComponent(request.url.search)).equals(
-        '?page=1&limit=10&sort_by={"name":"asc"}&search={"$and":[]}'
+        '?page=1&limit=10&sort_by={"name":"asc"}&search={"$or":[{"name":{"$rg":""}}]}'
       );
     });
 
@@ -98,58 +96,36 @@ describe('Agent configurations', () => {
 
     cy.waitForRequest('@getAgentConfigurations').then(({ request }) => {
       expect(decodeURIComponent(request.url.search)).equals(
-        '?page=1&limit=10&sort_by={"name":"desc"}&search={"$and":[]}'
+        '?page=1&limit=10&sort_by={"name":"desc"}&search={"$or":[{"name":{"$rg":""}}]}'
       );
     });
 
     cy.makeSnapshot();
   });
 
-  it('sends a listing request with the search bar content when after a delay', () => {
+  it('sends a request when the search and filters are updated', () => {
     initialize({});
 
-    cy.waitForRequest('@getAgentConfigurations');
-
-    cy.findAllByPlaceholderText(labelSearch).clear().type('My agent');
-
-    cy.wait(500);
-
     cy.waitForRequest('@getAgentConfigurations').then(({ request }) => {
-      expect(JSON.parse(request.url.searchParams.get('search'))).to.deep.equal({
-        $and: [{ $or: [{ name: { $rg: 'My agent' } }] }]
-      });
+      expect(decodeURIComponent(request.url.search)).equals(
+        '?page=1&limit=10&sort_by={"name":"asc"}&search={"$or":[{"name":{"$rg":""}}]}'
+      );
     });
-  });
 
-  it('sends a listing request when the filters are updated and search button clicked', () => {
-    initialize({});
-
-    cy.waitForRequest('@getAgentConfigurations');
-
-    cy.contains('AC 0');
+    cy.findAllByTestId('Search').find('input').type('My agent');
     cy.findByLabelText('Filters').click();
-
-    cy.findByLabelText(labelPoller).click({ force: true });
-    cy.waitForRequest('@getFilterPollers');
-    cy.contains('poller6').click();
-
     cy.findByLabelText(labelAgentType).click({ force: true });
     cy.get('[data-option-index="1"]').click();
+    cy.findByLabelText(labelPoller).click({ force: true });
 
-    cy.findAllByTestId(labelName).eq(1).clear().type('My agent');
+    cy.waitForRequest('@getFilterPollers');
 
-    cy.contains(labelSearch).click();
+    cy.contains('poller6').click();
 
     cy.waitForRequest('@getAgentConfigurations').then(({ request }) => {
-      expect(JSON.parse(request.url.searchParams.get('search'))).to.deep.equal({
-        $and: [
-          { $or: [{ name: { $rg: 'My agent' } }] },
-          { $or: [{ type: { $in: ['telegraf'] } }] },
-          {
-            $or: [{ 'poller.id': { $in: [6] } }]
-          }
-        ]
-      });
+      expect(decodeURIComponent(request.url.search)).equals(
+        '?page=1&limit=10&sort_by={"name":"asc"}&search={"$and":[{"$or":[{"name":{"$rg":"My agent"}}]},{"$and":[{"$or":[{"type":{"$in":["telegraf"]}}]},{"$or":[{"poller.id":{"$in":[6]}}]}]}]}'
+      );
     });
 
     cy.makeSnapshot();
@@ -160,7 +136,7 @@ describe('Agent configurations', () => {
 
     cy.waitForRequest('@getAgentConfigurations').then(({ request }) => {
       expect(decodeURIComponent(request.url.search)).equals(
-        '?page=1&limit=10&sort_by={"name":"asc"}&search={"$and":[]}'
+        '?page=1&limit=10&sort_by={"name":"asc"}&search={"$or":[{"name":{"$rg":""}}]}'
       );
     });
 
@@ -184,7 +160,7 @@ describe('Agent configurations', () => {
 
     cy.waitForRequest('@getAgentConfigurations').then(({ request }) => {
       expect(decodeURIComponent(request.url.search)).equals(
-        '?page=1&limit=10&sort_by={"name":"asc"}&search={"$and":[]}'
+        '?page=1&limit=10&sort_by={"name":"asc"}&search={"$or":[{"name":{"$rg":""}}]}'
       );
     });
 
@@ -203,38 +179,40 @@ describe('Agent configurations', () => {
   it('clears filters when filters are populated and the corresponding button is clicked', () => {
     initialize({});
 
-    // cy.waitForRequest('@getAgentConfigurations');
+    cy.waitForRequest('@getAgentConfigurations').then(({ request }) => {
+      expect(decodeURIComponent(request.url.search)).equals(
+        '?page=1&limit=10&sort_by={"name":"asc"}&search={"$or":[{"name":{"$rg":""}}]}'
+      );
+    });
+
+    cy.findAllByTestId('Search').find('input').type('My agent');
     cy.findByLabelText('Filters').click();
     cy.findByLabelText(labelAgentType).click({ force: true });
     cy.get('[data-option-index="1"]').click();
     cy.findByLabelText(labelPoller).click({ force: true });
 
     cy.waitForRequest('@getFilterPollers');
+
     cy.contains('poller6').click();
-
-    cy.findAllByTestId(labelName).eq(1).clear().type('My agent');
-
-    cy.contains(labelClear).click();
-
-    cy.waitForRequest('@getAgentConfigurations').then(({ request }) => {
-      expect(JSON.parse(request.url.searchParams.get('search'))).to.deep.equal({
-        $and: []
-      });
-    });
-
-    cy.findAllByTestId(labelName).eq(1).should('have.value', '');
+    cy.contains(labelClear).click({ force: true });
     cy.contains('poller6').should('not.exist');
     cy.contains('Centreon Monitoring Agent').should('not.exist');
 
+    cy.waitForRequest('@getAgentConfigurations').then(({ request }) => {
+      expect(decodeURIComponent(request.url.search)).equals(
+        '?page=1&limit=10&sort_by={"name":"asc"}&search={"$or":[{"name":{"$rg":"My agent"}}]}'
+      );
+    });
+
     cy.makeSnapshot();
   });
 
-  it('cancels an agent deletion when the corresponding icon is clicked and the corresponding is clicked', () => {
+  it('cancels a poller deletion when the corresponding icon is clicked and the corresponding is clicked', () => {
     initialize({});
 
     cy.waitForRequest('@getAgentConfigurations').then(({ request }) => {
       expect(decodeURIComponent(request.url.search)).equals(
-        '?page=1&limit=10&sort_by={"name":"asc"}&search={"$and":[]}'
+        '?page=1&limit=10&sort_by={"name":"asc"}&search={"$or":[{"name":{"$rg":""}}]}'
       );
     });
 
@@ -259,7 +237,7 @@ describe('Agent configurations', () => {
 
     cy.waitForRequest('@getAgentConfigurations').then(({ request }) => {
       expect(decodeURIComponent(request.url.search)).equals(
-        '?page=1&limit=10&sort_by={"name":"asc"}&search={"$and":[]}'
+        '?page=1&limit=10&sort_by={"name":"asc"}&search={"$or":[{"name":{"$rg":""}}]}'
       );
     });
 
@@ -287,7 +265,7 @@ describe('Agent configurations', () => {
 
     cy.waitForRequest('@getAgentConfigurations').then(({ request }) => {
       expect(decodeURIComponent(request.url.search)).equals(
-        '?page=1&limit=10&sort_by={"name":"asc"}&search={"$and":[]}'
+        '?page=1&limit=10&sort_by={"name":"asc"}&search={"$or":[{"name":{"$rg":""}}]}'
       );
     });
 
@@ -390,6 +368,7 @@ describe('Agent configurations modal', () => {
     cy.findByLabelText(labelName).type('agent');
     cy.findByLabelText(labelPollers).click();
     cy.contains('poller1').click();
+    cy.contains('Pollers').click();
     cy.findAllByLabelText(labelPort).eq(0).clear().type('1234');
     cy.findAllByLabelText(labelPublicCertificate).eq(0).type('test.crt');
     cy.findAllByLabelText(labelPrivateKey).eq(0).type('/sub/test.key');
@@ -490,9 +469,9 @@ describe('Agent configurations modal', () => {
     cy.findByLabelText(labelAgentType).click();
     cy.get('[data-option-index="1"]').click();
 
-    cy.findByLabelText(labelConnectionInitiatedByPoller).should(
-      'not.be.checked'
-    );
+    cy.findByTestId('By agent selected').should('be.visible');
+    cy.findByTestId('By poller selected').should('not.exist');
+    cy.contains(labelConnectionInitiated);
     cy.contains(labelOTLPReceiver).should('be.visible');
     cy.findByLabelText(labelPublicCertificate).should('have.value', '');
     cy.findAllByLabelText(labelCaCertificate).eq(0).should('have.value', '');
@@ -526,7 +505,7 @@ describe('Agent configurations modal', () => {
     cy.makeSnapshot();
   });
 
-  it('does not validate the form when there is no host configuration', () => {
+  it('does not validate the form when there mode "By poller" is enabled and there no host configuration', () => {
     initialize({});
 
     cy.contains(labelAdd).click();
@@ -536,18 +515,30 @@ describe('Agent configurations modal', () => {
     cy.findByLabelText(labelName).type('My agent');
     cy.findByLabelText(labelPollers).click();
     cy.contains('poller1').click();
+
+    cy.contains('Add agent configuration').click();
+    cy.contains(labelSave).scrollIntoView().should('be.disabled');
+
     cy.findByLabelText(labelPublicCertificate).type('test.crt');
     cy.findByLabelText(labelCaCertificate).type('test.crt');
     cy.findByLabelText(labelPrivateKey).type('test.key');
 
-    cy.findByLabelText(labelConnectionInitiatedByPoller).click();
+    cy.findByLabelText(labelSelectExistingCMATokens).click();
+    cy.waitForRequest('@getTokens');
+    cy.contains('token 1').click();
 
-    cy.contains(labelSave).scrollIntoView().should('be.disabled');
+    cy.contains('By poller').click();
+
+    cy.contains('Enable').click();
+    cy.findByTestId('submit').should('be.disabled');
+
+    cy.contains('Enable').click();
+    cy.findByTestId('submit').should('not.be.disabled');
 
     cy.makeSnapshot();
   });
 
-  it('validates the form when fields are filled and the reverse switch is unchecked', () => {
+  it('validates the form when fields are filled and the only "By agent" mode is unchecked', () => {
     initialize({});
 
     cy.contains(labelAdd).click();
@@ -557,6 +548,7 @@ describe('Agent configurations modal', () => {
     cy.findByLabelText(labelName).type('My agent');
     cy.findByLabelText(labelPollers).click();
     cy.contains('poller1').click();
+    cy.contains('Add agent configuration').click();
 
     cy.findByLabelText(labelPublicCertificate).type('/certificate/test.crt');
     cy.findByLabelText(labelCaCertificate).type('test.crt');
@@ -575,8 +567,9 @@ describe('Agent configurations modal', () => {
         type: 'centreon-agent',
         poller_ids: [1],
         configuration: {
+          agent_initiated: true,
+          poller_initiated: false,
           tokens: [{ name: 'token 1', creator_id: 1 }],
-          is_reverse: false,
           otel_ca_certificate: 'test.crt',
           otel_public_certificate: '/certificate/test.crt',
           otel_private_key: 'privateKey.key',
@@ -594,7 +587,10 @@ describe('Agent configurations modal', () => {
     cy.contains(labelAdd).click();
     cy.findByLabelText(labelAgentType).click();
     cy.get('[data-option-index="1"]').click();
-    cy.findByLabelText(labelConnectionInitiatedByPoller).click();
+
+    cy.contains(labelByPoller).click();
+
+    cy.contains('Enable').click();
     cy.findByLabelText(labelSelectHost).click();
 
     cy.waitForRequest('@getHosts');
@@ -602,7 +598,7 @@ describe('Agent configurations modal', () => {
     cy.contains('central').click();
 
     cy.findByLabelText(labelDNSIP).should('have.value', '127.0.0.2');
-    cy.findByTestId(labelPort).find('input').should('have.value', '4317');
+    cy.findByTestId('portInput').should('have.value', '4317');
 
     cy.makeSnapshot();
   });
@@ -613,10 +609,13 @@ describe('Agent configurations modal', () => {
     cy.contains(labelAdd).click();
     cy.findByLabelText(labelAgentType).click();
     cy.get('[data-option-index="1"]').click();
-    cy.findByLabelText(labelConnectionInitiatedByPoller).click();
+    cy.contains(labelByPoller).click();
+
+    cy.contains('Enable').click();
+
     cy.findByLabelText(labelDNSIP).type('127.0.0.1:8');
     cy.findByLabelText(labelDNSIP).should('have.value', '127.0.0.1');
-    cy.findByTestId(labelPort).find('input').should('have.value', '8');
+    cy.findByTestId('portInput').should('have.value', '8');
 
     cy.makeSnapshot();
   });
@@ -627,10 +626,12 @@ describe('Agent configurations modal', () => {
     cy.contains(labelAdd).click();
     cy.findByLabelText(labelAgentType).click();
     cy.get('[data-option-index="1"]').click();
-    cy.findByLabelText(labelConnectionInitiatedByPoller).click();
+    cy.contains(labelByPoller).click();
+    cy.contains('Enable').click();
 
     cy.contains(labelAddAHost).click();
 
+    cy.findByTestId('delete-host-configuration-0').should('be.visible');
     cy.findByTestId('delete-host-configuration-1').should('exist');
 
     cy.makeSnapshot();
@@ -642,12 +643,19 @@ describe('Agent configurations modal', () => {
     cy.contains(labelAdd).click();
     cy.findByLabelText(labelAgentType).click();
     cy.get('[data-option-index="1"]').click();
-    cy.findByLabelText(labelConnectionInitiatedByPoller).click();
+
+    cy.contains(labelByPoller).click();
+    cy.contains('Enable').click();
+
+    cy.contains(labelSave).scrollIntoView();
 
     cy.contains(labelAddAHost).click();
 
+    cy.findByTestId('delete-host-configuration-1').should('exist');
+
     cy.findByTestId('delete-host-configuration-1').click();
 
+    cy.findByTestId('delete-host-configuration-0').should('be.disabled');
     cy.findByTestId('delete-host-configuration-1').should('not.exist');
 
     cy.makeSnapshot();
@@ -659,26 +667,28 @@ describe('Agent configurations modal', () => {
     cy.contains(labelAdd).click();
     cy.findByLabelText(labelAgentType).click();
     cy.get('[data-option-index="1"]').click();
-    cy.findByLabelText(labelConnectionInitiatedByPoller).click();
     cy.findByLabelText(labelName).type('My agent');
     cy.findByLabelText(labelPollers).click();
     cy.contains('poller1').click();
+    cy.contains(labelConnectionInitiated).click({ force: true });
     cy.findByLabelText(labelPublicCertificate).type('/test.cer');
     cy.findAllByLabelText(labelCaCertificate).eq(0).type('test.crt');
-    cy.findAllByLabelText(labelCaCertificate).eq(1).type('test.crt');
     cy.findAllByLabelText(labelPrivateKey).eq(0).type('private.key');
+    cy.findByLabelText(labelSelectExistingCMATokens).click();
+    cy.waitForRequest('@getTokens');
+    cy.contains('token 1').click();
+
+    cy.contains(labelByPoller).click();
+    cy.contains('Enable').click();
     cy.findByLabelText(labelSelectHost).click();
     cy.contains('central').click();
+    cy.findByLabelText(labelCaCertificate).type('test.crt');
     cy.findByLabelText(labelCACommonName).type('test.crt');
 
-    cy.findByTestId('submit').should('be.disabled');
-
     cy.findByLabelText(labelSelectExistingCMAToken).click();
     cy.waitForRequest('@getTokens');
     cy.contains('token 1').click();
 
-    cy.findByLabelText(labelCMAauthenticationToken).should('not.exist');
-
     cy.findByTestId('submit').click();
 
     cy.waitForRequest('@postAgentConfiguration').then(({ request }) => {
@@ -688,8 +698,9 @@ describe('Agent configurations modal', () => {
         connection_mode: 'secure',
         poller_ids: [1],
         configuration: {
-          tokens: [],
-          is_reverse: true,
+          tokens: [{ name: 'token 1', creator_id: 1 }],
+          agent_initiated: true,
+          poller_initiated: true,
           otel_ca_certificate: 'test.crt',
           otel_public_certificate: '/test.cer',
           otel_private_key: 'private.key',
@@ -803,12 +814,13 @@ describe('Agent configurations modal', () => {
     cy.findByLabelText(labelEncryptionLevel).click();
     cy.contains(labelNoTLS).click();
 
-    cy.findByLabelText(labelConnectionInitiatedByPoller).click();
-
     cy.findByLabelText(labelPublicCertificate).should('not.exist');
     cy.findAllByLabelText(labelCaCertificate).should('not.exist');
-    cy.findAllByLabelText(labelCaCertificate).should('not.exist');
     cy.findAllByLabelText(labelPrivateKey).should('not.exist');
+
+    cy.contains(labelByPoller).click();
+    cy.contains('Enable').click();
+
     cy.findByLabelText(labelSelectHost).click();
     cy.contains('central').click();
     cy.findByLabelText(labelCACommonName).should('not.exist');
@@ -825,7 +837,8 @@ describe('Agent configurations modal', () => {
         connection_mode: 'no-tls',
         poller_ids: [1],
         configuration: {
-          is_reverse: true,
+          agent_initiated: true,
+          poller_initiated: true,
           tokens: [],
           otel_ca_certificate: null,
           otel_public_certificate: null,
@@ -861,6 +874,7 @@ describe('Agent configurations modal', () => {
     cy.findByLabelText(labelName).type('Insecure Agent');
     cy.findByLabelText(labelPollers).click();
     cy.contains('poller1').click();
+    cy.contains('Add agent configuration').click();
     cy.findAllByLabelText(labelPort).eq(0).clear().type('1234');
 
     cy.findAllByLabelText(labelPublicCertificate).eq(0).should('exist');
