@@ -3,7 +3,7 @@ import { platformFeaturesAtom, userAtom } from '@centreon/ui-context';
 import i18next from 'i18next';
 import { Provider, createStore } from 'jotai';
 import { initReactI18next } from 'react-i18next';
-import { BrowserRouter as Router } from 'react-router-dom';
+import { BrowserRouter as Router } from 'react-router';
 import AgentConfigurationPage from '../Page';
 import {
   agentConfigurationPollersEndpoint,
