@@ -1,5 +1,6 @@
 export enum Provider {
   Local = 'local',
   Openid = 'openid',
-  WebSSO = 'web-sso',
+  SAML = 'saml',
+  WebSSO = 'web-sso'
 }
