@@ -8,6 +8,7 @@ import { SelectEntry } from '@centreon/ui';
 
 import {
   labelCustomize,
+  labelLast2Months,
   labelLast3Hours,
   labelLast3Months,
   labelLast6Hours,
@@ -15,6 +16,7 @@ import {
   labelLast7Days,
   labelLast12Hours,
   labelLast12Months,
+  labelLast14Days,
   labelLast24Hours,
   labelLast30Days,
   labelLastHour
@@ -50,10 +52,18 @@ export const options: Array<SelectEntry> = [
     id: 7 * day,
     name: labelLast7Days
   },
+  {
+    id: 14 * day,
+    name: labelLast14Days
+  },
   {
     id: month * day,
     name: labelLast30Days
   },
+  {
+    id: 2 * month * day,
+    name: labelLast2Months
+  },
   {
     id: 3 * month * day,
     name: labelLast3Months
@@ -99,8 +109,8 @@ const useTimePeriod = (propertyName: string): UseTimePeriodState => {
 
     if (equals(newType, -1)) {
       setFieldValue(`options.${propertyName}`, {
-        end: dayjs(),
-        start: dayjs().subtract(1, 'hour'),
+        end: dayjs().toISOString(),
+        start: dayjs().subtract(1, 'hour').toISOString(),
         timePeriodType: newType
       });
 
