@@ -26,17 +26,23 @@ import {
   labelMoreActions
 } from '../DashboardListing/translatedLabels';
 
+import FavoriteAction from '../DashboardListing/Actions/favoriteAction';
 import { useStyles } from './DashboardCardActions.styles';
 import useDashboardCardActions from './useDashboardCardActions';
 
 interface Props {
   dashboard: Dashboard;
+  refetch?: () => void;
+  isFetchingListing: boolean;
 }
 
-const DashboardCardActions = ({ dashboard }: Props): JSX.Element => {
+const DashboardCardActions = ({
+  dashboard,
+  refetch,
+  isFetchingListing
+}: Props): JSX.Element => {
   const { classes } = useStyles();
   const { t } = useTranslation();
-
   const {
     moreActionsOpen,
     openDeleteModal,
@@ -57,6 +63,12 @@ const DashboardCardActions = ({ dashboard }: Props): JSX.Element => {
 
   return (
     <div className={classes.container}>
+      <FavoriteAction
+        dashboardId={dashboard.id as number}
+        isFavorite={dashboard?.isFavorite as boolean}
+        refetch={refetch}
+        isFetching={isFetchingListing}
+      />
       <IconButton
         ariaLabel={labels.labelShareWithContacts}
         title={labels.labelShareWithContacts}
