@@ -19,6 +19,9 @@
  *
  */
 
+use Adaptation\Log\LoggerPassword;
+use Core\Common\Domain\Exception\RepositoryException;
+
 require_once __DIR__ . '/../../../class/centreonContact.class.php';
 require_once __DIR__ . '/../../../class/centreonAuth.class.php';
 
@@ -82,7 +85,15 @@ function updateNotificationOptions($contact_id)
     unset($_SESSION['centreon_notification_preferences']);
 }
 
-function updateContactInDB($contact_id = null)
+/**
+ * @param $contact_id
+ *
+ * @throws InvalidArgumentException
+ * @throws PDOException
+ * @throws RepositoryException
+ * @return void
+ */
+function updateContactInDB($contact_id = null): void
 {
     if (! $contact_id) {
         return;
@@ -91,7 +102,14 @@ function updateContactInDB($contact_id = null)
     updateNotificationOptions($contact_id);
 }
 
-function updateContact($contactId = null)
+/**
+ * @param $contactId
+ *
+ * @throws PDOException
+ * @throws RepositoryException
+ * @return void
+ */
+function updateContact($contactId = null): void
 {
     global $form, $pearDB, $centreon;
 
@@ -161,9 +179,30 @@ function updateContact($contactId = null)
 
     if (isset($submitValues['contact_passwd']) && ! empty($submitValues['contact_passwd'])) {
         $hashedPassword = password_hash($submitValues['contact_passwd'], CentreonAuth::PASSWORD_HASH_ALGORITHM);
-        $contact = new CentreonContact($pearDB);
-        $contact->renewPasswordByContactId($contactId, $hashedPassword);
-        $centreon->user->setPasswd($hashedPassword);
+
+        try {
+            $contact = new CentreonContact($pearDB);
+            $contact->renewPasswordByContactId($contactId, $hashedPassword);
+
+            $centreon->user->setPasswd($hashedPassword);
+
+            LoggerPassword::create()->success(
+                initiatorId: (int) $centreon->user->get_id(),
+                targetId: (int) $centreon->user->get_id(),
+            );
+        } catch (PDOException $e) {
+            LoggerPassword::create()->warning(
+                reason: 'password update failed',
+                initiatorId: (int) $centreon->user->get_id(),
+                targetId: (int) $centreon->user->get_id(),
+                exception: $e
+            );
+
+            throw new RepositoryException(
+                message: 'Unable to update password for contact id ' . $contactId,
+                previous: $e
+            );
+        }
     }
 
     // Update user object..
@@ -194,21 +233,45 @@ function validatePasswordModification(array $fields): array|true
 
     // If the user only provided a confirmation password, he must provide a new password and a current password
     if (empty($newPassword) && ! empty($confirmPassword) && empty($currentPassword)) {
+        LoggerPassword::create()->warning(
+            reason: 'new password or current password not provided',
+            initiatorId: (int) $centreon->user->get_id(),
+            targetId: (int) $centreon->user->get_id(),
+        );
+
         return ['contact_passwd2' => _('Please fill in all password fields')];
     }
 
     // If the user only provided his current password, he must provide a new password
     if (empty($newPassword) && ! empty($currentPassword)) {
+        LoggerPassword::create()->warning(
+            reason: 'new password not provided',
+            initiatorId: (int) $centreon->user->get_id(),
+            targetId: (int) $centreon->user->get_id(),
+        );
+
         return ['current_password' => _('Please fill in all password fields')];
     }
 
     // If the user wants to change his password, he must provide his current password
     if (! empty($newPassword) && empty($currentPassword)) {
+        LoggerPassword::create()->warning(
+            reason: 'current password not provided',
+            initiatorId: (int) $centreon->user->get_id(),
+            targetId: (int) $centreon->user->get_id(),
+        );
+
         return ['current_password' => _('Please fill in all password fields')];
     }
 
     // If the user provided a current password, we check if it matches the one in the database
     if (! empty($currentPassword) && password_verify($currentPassword, $centreon->user->passwd) === false) {
+        LoggerPassword::create()->warning(
+            reason: 'current password wrong',
+            initiatorId: (int) $centreon->user->get_id(),
+            targetId: (int) $centreon->user->get_id(),
+        );
+
         return ['current_password' => _('Authentication failed')];
     }
 
@@ -217,7 +280,14 @@ function validatePasswordModification(array $fields): array|true
         $contact->respectPasswordPolicyOrFail($newPassword, $contactId);
 
         return true;
-    } catch (Throwable $e) {
+    } catch (Exception $e) {
+        LoggerPassword::create()->warning(
+            reason: 'new password does not respect password policy',
+            initiatorId: (int) $centreon->user->get_id(),
+            targetId: (int) $centreon->user->get_id(),
+            exception: $e,
+        );
+
         return ['contact_passwd' => $e->getMessage()];
     }
 }
@@ -251,6 +321,12 @@ function checkAutologinValue(array $fields)
             $errorMessage = _('Your new password and autologin key must be different');
             $errors['contact_passwd'] = $errorMessage;
             $errors['contact_autologin_key'] = $errorMessage;
+
+            LoggerPassword::create()->warning(
+                reason: 'new password and autologin key are the same',
+                initiatorId: (int) $centreon->user->get_id(),
+                targetId: (int) $centreon->user->get_id(),
+            );
         }
     }
 
@@ -301,11 +377,6 @@ function updateNonLocalContactInDB($contact_id = null): void
     $stmt->bindValue(':contactId', $contact_id, PDO::PARAM_INT);
     $stmt->execute();
     $stmt->closeCursor();
-    if (! empty($ret['contact_passwd'])) {
-        $hashedPassword = password_hash($ret['contact_passwd'], CentreonAuth::PASSWORD_HASH_ALGORITHM);
-        $contact = new CentreonContact($pearDB);
-        $contact->renewPasswordByContactId($contact_id, $hashedPassword);
-    }
 
     // Update user object..
     $centreon->user->lang = $ret['contact_lang'];
