@@ -21,8 +21,10 @@
 
 use Adaptation\Database\Connection\Collection\QueryParameters;
 use Adaptation\Database\Connection\ValueObject\QueryParameter;
+use Adaptation\Log\LoggerPassword;
 use App\Kernel;
 use Centreon\Domain\Log\Logger;
+use Core\Common\Domain\Exception\RepositoryException;
 
 if (! isset($centreon)) {
     exit();
@@ -197,7 +199,7 @@ function unblockContactInDB(int|array|null $contact = null): void
 {
     global $pearDB, $centreon;
 
-    if (null === $contact || [] === $contact) {
+    if ($contact === null || $contact === []) {
         return;
     }
 
@@ -537,8 +539,13 @@ function multipleContactInDB($contacts = [], $nbrDup = [])
 /**
  * @param null $contact_id
  * @param bool $from_MC
+ * @param bool $isRemote
+ *
+ * @throws InvalidArgumentException
+ * @throws PDOException
+ * @throws RepositoryException
  */
-function updateContactInDB($contact_id = null, $from_MC = false, bool $isRemote = false)
+function updateContactInDB($contact_id = null, $from_MC = false, bool $isRemote = false): void
 {
     global $form;
 
@@ -678,9 +685,13 @@ function insertContact($ret = [])
 }
 
 /**
- * @param int|null $contactId
+ * @param null $contactId
+ *
+ * @throws InvalidArgumentException
+ * @throws PDOException
+ * @throws RepositoryException
  */
-function updateContact($contactId = null)
+function updateContact($contactId = null): void
 {
     global $form, $pearDB, $centreon, $encryptType, $dependencyInjector;
     if (! $contactId) {
@@ -721,8 +732,27 @@ function updateContact($contactId = null)
         $ret['contact_passwd'] = password_hash($ret['contact_passwd'], CentreonAuth::PASSWORD_HASH_ALGORITHM);
         $ret['contact_passwd2'] = $ret['contact_passwd'];
 
-        $contact = new CentreonContact($pearDB);
-        $contact->renewPasswordByContactId($contactId, $ret['contact_passwd']);
+        try {
+            $contact = new CentreonContact($pearDB);
+            $contact->renewPasswordByContactId($contactId, $ret['contact_passwd']);
+
+            LoggerPassword::create()->success(
+                initiatorId: (int) $centreon->user->get_id(),
+                targetId: (int) $contactId,
+            );
+        } catch (PDOException $e) {
+            LoggerPassword::create()->warning(
+                reason: 'password update failed',
+                initiatorId: (int) $centreon->user->get_id(),
+                targetId: (int) $contactId,
+                exception: $e,
+            );
+
+            throw new RepositoryException(
+                message: 'Unable to update password for contact id ' . $contactId,
+                previous: $e
+            );
+        }
     }
 
     // Prepare value for changelog
@@ -1248,7 +1278,7 @@ function insertLdapContactInDB($tmpContacts = [])
             $pearDB->query(sprintf($sqlUpdate, $tmplSql));
         }
         $listGroup = [];
-        if (false !== $ldap->connect()) {
+        if ($ldap->connect() !== false) {
             $listGroup = $ldap->listGroupsForUser($tmpContacts['dn'][$select_key]);
         }
         if ($listGroup !== []) {
@@ -1590,9 +1620,10 @@ function sanitizeFormContactParameters(array $ret): array
  * Validate password creation using defined security policy.
  *
  * @param array $fields
- * @return mixed
+ *
+ * @return array|true
  */
-function validatePasswordCreation(array $fields)
+function validatePasswordCreation(array $fields): true|array
 {
     global $pearDB;
     $errors = [];
@@ -1606,8 +1637,15 @@ function validatePasswordCreation(array $fields)
     try {
         $contact = new CentreonContact($pearDB);
         $contact->respectPasswordPolicyOrFail($password, null);
-    } catch (Throwable $e) {
+    } catch (Exception $e) {
         $errors['contact_passwd'] = $e->getMessage();
+
+        LoggerPassword::create()->warning(
+            reason: 'new password does not respect the password policy',
+            initiatorId: $fields['contact_id'] ?? 'unknown',
+            targetId: $fields['contact_id'] ?? 'unknown',
+            exception: $e,
+        );
     }
 
     return $errors !== [] ? $errors : true;
@@ -1635,21 +1673,45 @@ function validatePasswordModification(array $fields): array|true
 
     // If the user only provided a confirmation password, he must provide a new password and a current password
     if (empty($newPassword) && ! empty($confirmPassword) && empty($currentPassword)) {
+        LoggerPassword::create()->warning(
+            reason: 'new password or current password not provided',
+            initiatorId: (int) $centreon->user->get_id(),
+            targetId: (int) $contactId,
+        );
+
         return ['contact_passwd2' => _('Please fill in all password fields')];
     }
 
     // If the user only provided his current password, he must provide a new password
     if (empty($newPassword) && ! empty($currentPassword)) {
+        LoggerPassword::create()->warning(
+            reason: 'new password not provided',
+            initiatorId: (int) $centreon->user->get_id(),
+            targetId: (int) $contactId,
+        );
+
         return ['current_password' => _('Please fill in all password fields')];
     }
 
     // If the user wants to change his password, he must provide his current password
     if (! empty($newPassword) && empty($currentPassword)) {
+        LoggerPassword::create()->warning(
+            reason: 'current password not provided',
+            initiatorId: (int) $centreon->user->get_id(),
+            targetId: (int) $contactId,
+        );
+
         return ['current_password' => _('Please fill in all password fields')];
     }
 
     // If the user provided a current password, we check if it matches the one in the database
     if (! empty($currentPassword) && password_verify($currentPassword, $centreon->user->passwd) === false) {
+        LoggerPassword::create()->warning(
+            reason: 'current password wrong',
+            initiatorId: (int) $centreon->user->get_id(),
+            targetId: (int) $contactId,
+        );
+
         return ['current_password' => _('Authentication failed')];
     }
 
@@ -1658,7 +1720,14 @@ function validatePasswordModification(array $fields): array|true
         $contact->respectPasswordPolicyOrFail($newPassword, $contactId);
 
         return true;
-    } catch (Throwable $e) {
+    } catch (Exception $e) {
+        LoggerPassword::create()->warning(
+            reason: 'new password does not respect the password policy',
+            initiatorId: (int) $centreon->user->get_id(),
+            targetId: (int) $contactId,
+            exception: $e,
+        );
+
         return ['contact_passwd' => $e->getMessage()];
     }
 }
@@ -1693,6 +1762,12 @@ function validateAutologin(array $fields)
                 $errors['contact_autologin_key'] = _(
                     'Your autologin key must be different than your current password'
                 );
+
+                LoggerPassword::create()->warning(
+                    reason: 'autologin key is the same as current password',
+                    initiatorId: (int) $fields['contact_id'],
+                    targetId: (int) $fields['contact_id'],
+                );
             }
         }
         if (
@@ -1702,6 +1777,12 @@ function validateAutologin(array $fields)
             $errorMessage = 'Your password and autologin key should be different';
             $errors['contact_passwd'] = _($errorMessage);
             $errors['contact_autologin_key'] = _($errorMessage);
+
+            LoggerPassword::create()->warning(
+                reason: 'autologin key is the same as new password',
+                initiatorId: (int) $fields['contact_id'],
+                targetId: (int) $fields['contact_id'],
+            );
         }
     }
 
