@@ -1,13 +1,13 @@
 <?php
 
-/**
- * Copyright 2005 - 2022 Centreon (https://www.centreon.com/)
+/*
+ * Copyright 2005 - 2025 Centreon (https://www.centreon.com/)
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
  * You may obtain a copy of the License at
  *
- * http://www.apache.org/licenses/LICENSE-2.0
+ * https://www.apache.org/licenses/LICENSE-2.0
  *
  * Unless required by applicable law or agreed to in writing, software
  * distributed under the License is distributed on an "AS IS" BASIS,
@@ -19,8 +19,8 @@
  *
  */
 
-require_once "../require.php";
-require_once "functions.php";
+require_once '../require.php';
+require_once 'functions.php';
 require_once $centreon_path . 'www/class/centreon.class.php';
 require_once $centreon_path . 'www/class/centreonSession.class.php';
 require_once $centreon_path . 'www/class/centreonWidget.class.php';
@@ -32,7 +32,7 @@ require_once $centreon_path . 'bootstrap.php';
 
 CentreonSession::start(1);
 
-if (!isset($_SESSION['centreon']) || !isset($_REQUEST['widgetId'])) {
+if (! isset($_SESSION['centreon']) || ! isset($_REQUEST['widgetId'])) {
     exit;
 }
 
@@ -60,24 +60,25 @@ try {
         $autoRefresh = 30;
     }
     $variablesThemeCSS = match ($centreon->user->theme) {
-        'light' => "Generic-theme",
-        'dark' => "Centreon-Dark",
-        default => throw new \Exception('Unknown user theme : ' . $centreon->user->theme),
+        'light' => 'Generic-theme',
+        'dark' => 'Centreon-Dark',
+        default => throw new Exception('Unknown user theme : ' . $centreon->user->theme),
     };
 } catch (Exception $e) {
-    echo $e->getMessage() . "<br/>";
+    echo $e->getMessage() . '<br/>';
+
     exit;
 }
 
-$kernel = \App\Kernel::createForWeb();
+$kernel = App\Kernel::createForWeb();
 /**
  * @var Centreon\Application\Controller\MonitoringResourceController $resourceController
  */
 $resourceController = $kernel->getContainer()->get(
-    \Centreon\Application\Controller\MonitoringResourceController::class
+    Centreon\Application\Controller\MonitoringResourceController::class
 );
 
-//configure smarty
+// configure smarty
 $isAdmin = $centreon->user->admin === '1';
 $accessGroups = [];
 if (! $isAdmin) {
@@ -85,9 +86,10 @@ if (! $isAdmin) {
     $accessGroups = $access->getAccessGroups();
 }
 
-$path = $centreon_path . "www/widgets/single-metric/src/";
-$template = new Smarty();
-$template = initSmartyTplForPopup($path, $template, "./", $centreon_path);
+// Smarty template initialization
+$path = $centreon_path . 'www/widgets/single-metric/src/';
+$template = SmartyBC::createSmartyTemplate($path, './');
+
 $template->assign('theme', $variablesThemeCSS);
 $template->assign(
     'webTheme',
@@ -98,14 +100,14 @@ $template->assign(
 
 $data = [];
 
-if (! isset($preferences['service']) || $preferences['service'] === "") {
+if (! isset($preferences['service']) || $preferences['service'] === '') {
     $template->display('metric.ihtml');
 } else {
-    [$hostId, $serviceId] = explode("-", $preferences['service']);
+    [$hostId, $serviceId] = explode('-', $preferences['service']);
     $numLine = 0;
     if ($isAdmin || ! empty($accessGroups)) {
-        $query =
-            "SELECT
+        $query
+            = "SELECT
                 1 AS REALTIME,
                 i.host_name AS host_name,
                 i.service_description AS service_description,
@@ -121,21 +123,21 @@ if (! isset($preferences['service']) || $preferences['service'] === "") {
             FROM
                 metrics m,
                 hosts h "
-                    . (!$isAdmin ? ", centreon_acl acl " : "")
-                    . " , index_data i
+                    . (! $isAdmin ? ', centreon_acl acl ' : '')
+                    . ' , index_data i
             LEFT JOIN services s ON s.service_id  = i.service_id AND s.enabled = 1
             WHERE i.service_id = :serviceId
             AND i.id = m.index_id
             AND m.metric_name = :metricName
             AND i.host_id = h.host_id 
-            AND i.host_id = :hostId ";
-        if (!$isAdmin) {
-            $query .= "AND i.host_id = acl.host_id
+            AND i.host_id = :hostId ';
+        if (! $isAdmin) {
+            $query .= 'AND i.host_id = acl.host_id
                 AND i.service_id = acl.service_id
-                AND acl.group_id IN (" . implode(',', array_keys($accessGroups)) . ")";
+                AND acl.group_id IN (' . implode(',', array_keys($accessGroups)) . ')';
         }
-        $query .= "AND s.enabled = 1
-            AND h.enabled = 1;";
+        $query .= 'AND s.enabled = 1
+            AND h.enabled = 1;';
 
         $stmt = $centreonRtDb->prepare($query);
         $stmt->bindParam(':hostId', $hostId, PDO::PARAM_INT);
@@ -152,7 +154,7 @@ if (! isset($preferences['service']) || $preferences['service'] === "") {
         }
     }
 
-    /* Calculate Threshold font size */
+    // Calculate Threshold font size
     $preferences['threshold_font_size'] = round($preferences['font_size'] / 8, 0);
     if ($preferences['threshold_font_size'] < 9) {
         $preferences['threshold_font_size'] = 9;
@@ -166,14 +168,14 @@ if (! isset($preferences['service']) || $preferences['service'] === "") {
                 $data[0]['unit_name'],
                 $preferences['display_number']
             );
-            $data[0]['value_displayed'] = str_replace(".", ",", (string) $size);
+            $data[0]['value_displayed'] = str_replace('.', ',', (string) $size);
             if (is_numeric($data[0]['warning'])) {
                 $newWarning = convertSizeToHumanReadable(
                     $data[0]['warning'],
                     $data[0]['unit_name'],
                     $preferences['display_number']
                 );
-                $data[0]['warning_displayed'] = str_replace(".", ",", (string) $newWarning[0]);
+                $data[0]['warning_displayed'] = str_replace('.', ',', (string) $newWarning[0]);
             }
             if (is_numeric($data[0]['critical'])) {
                 $newCritical = convertSizeToHumanReadable(
@@ -181,7 +183,7 @@ if (! isset($preferences['service']) || $preferences['service'] === "") {
                     $data[0]['unit_name'],
                     $preferences['display_number']
                 );
-                $data[0]['critical_displayed'] = str_replace(".", ",", (string) $newCritical[0]);
+                $data[0]['critical_displayed'] = str_replace('.', ',', (string) $newCritical[0]);
             }
         } else {
             $data[0]['value_displayed'] = $data[0]['current_value'];
